# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field
from typing import Optional
from typing_extensions import Annotated
from unicourt.model.access_token_id_list_response import AccessTokenIdListResponse
from unicourt.model.access_token_request import AccessTokenRequest
from unicourt.model.access_token_response import AccessTokenResponse
from unicourt.model.invalidate_access_token_request import InvalidateAccessTokenRequest
from unicourt.model.success import Success

from unicourt.api_client import ApiClient, RequestSerialized
from unicourt.api_response import ApiResponse
from unicourt.rest import RESTResponseType


class AuthenticationApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def generate_new_token(
        self,
        access_token_request: Annotated[Optional[AccessTokenRequest], Field(description="The endpoint accepts your Client ID and Client Secret ID as part of the request.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AccessTokenResponse:
        """Generate new token to access API.

        This endpoint allows you to generate a new access token, which is a required field for all UniCourt API endpoints except for the Authentication API. To generate a new token, you must provide your Client ID and Client Secret ID which you can find by logging into your UniCourt account. At any time, you can have a maximum of 10 active access tokens. The tokens never expire and, if you make a request which would otherwise lead to you having more than 10 active tokens, you will receive an error message.

        :param access_token_request: The endpoint accepts your Client ID and Client Secret ID as part of the request.
        :type access_token_request: AccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._generate_new_token_serialize(
            access_token_request=access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AccessTokenResponse",
            '400': "Exception",
            '403': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def generate_new_token_with_http_info(
        self,
        access_token_request: Annotated[Optional[AccessTokenRequest], Field(description="The endpoint accepts your Client ID and Client Secret ID as part of the request.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AccessTokenResponse]:
        """Generate new token to access API.

        This endpoint allows you to generate a new access token, which is a required field for all UniCourt API endpoints except for the Authentication API. To generate a new token, you must provide your Client ID and Client Secret ID which you can find by logging into your UniCourt account. At any time, you can have a maximum of 10 active access tokens. The tokens never expire and, if you make a request which would otherwise lead to you having more than 10 active tokens, you will receive an error message.

        :param access_token_request: The endpoint accepts your Client ID and Client Secret ID as part of the request.
        :type access_token_request: AccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._generate_new_token_serialize(
            access_token_request=access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AccessTokenResponse",
            '400': "Exception",
            '403': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def generate_new_token_without_preload_content(
        self,
        access_token_request: Annotated[Optional[AccessTokenRequest], Field(description="The endpoint accepts your Client ID and Client Secret ID as part of the request.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Generate new token to access API.

        This endpoint allows you to generate a new access token, which is a required field for all UniCourt API endpoints except for the Authentication API. To generate a new token, you must provide your Client ID and Client Secret ID which you can find by logging into your UniCourt account. At any time, you can have a maximum of 10 active access tokens. The tokens never expire and, if you make a request which would otherwise lead to you having more than 10 active tokens, you will receive an error message.

        :param access_token_request: The endpoint accepts your Client ID and Client Secret ID as part of the request.
        :type access_token_request: AccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._generate_new_token_serialize(
            access_token_request=access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AccessTokenResponse",
            '400': "Exception",
            '403': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _generate_new_token_serialize(
        self,
        access_token_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if access_token_request is not None:
            _body_params = access_token_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/generateNewToken',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def invalidate_all_tokens(
        self,
        access_token_request: Annotated[Optional[AccessTokenRequest], Field(description="The endpoint accepts your Client ID and Secret Client ID as part of the request.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Success:
        """API to invalidate all access tokens.

        An endpoint which allows you to invalidate all existing access tokens associated with your UniCourt account.

        :param access_token_request: The endpoint accepts your Client ID and Secret Client ID as part of the request.
        :type access_token_request: AccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._invalidate_all_tokens_serialize(
            access_token_request=access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Success",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def invalidate_all_tokens_with_http_info(
        self,
        access_token_request: Annotated[Optional[AccessTokenRequest], Field(description="The endpoint accepts your Client ID and Secret Client ID as part of the request.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Success]:
        """API to invalidate all access tokens.

        An endpoint which allows you to invalidate all existing access tokens associated with your UniCourt account.

        :param access_token_request: The endpoint accepts your Client ID and Secret Client ID as part of the request.
        :type access_token_request: AccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._invalidate_all_tokens_serialize(
            access_token_request=access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Success",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def invalidate_all_tokens_without_preload_content(
        self,
        access_token_request: Annotated[Optional[AccessTokenRequest], Field(description="The endpoint accepts your Client ID and Secret Client ID as part of the request.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """API to invalidate all access tokens.

        An endpoint which allows you to invalidate all existing access tokens associated with your UniCourt account.

        :param access_token_request: The endpoint accepts your Client ID and Secret Client ID as part of the request.
        :type access_token_request: AccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._invalidate_all_tokens_serialize(
            access_token_request=access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Success",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _invalidate_all_tokens_serialize(
        self,
        access_token_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if access_token_request is not None:
            _body_params = access_token_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/invalidateAllTokens',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def invalidate_token(
        self,
        invalidate_access_token_request: Annotated[Optional[InvalidateAccessTokenRequest], Field(description="The endpoint accepts your Client ID, Client Secret ID and the Token ID for the access token you wish to invalidate as part of the request. You can obtain a list of all Token IDs from the /listAllTokenIds endpoint within this API.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Success:
        """API to invalidate the access token.

        An endpoint which allows you to invalidate a given access token.

        :param invalidate_access_token_request: The endpoint accepts your Client ID, Client Secret ID and the Token ID for the access token you wish to invalidate as part of the request. You can obtain a list of all Token IDs from the /listAllTokenIds endpoint within this API.
        :type invalidate_access_token_request: InvalidateAccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._invalidate_token_serialize(
            invalidate_access_token_request=invalidate_access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Success",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def invalidate_token_with_http_info(
        self,
        invalidate_access_token_request: Annotated[Optional[InvalidateAccessTokenRequest], Field(description="The endpoint accepts your Client ID, Client Secret ID and the Token ID for the access token you wish to invalidate as part of the request. You can obtain a list of all Token IDs from the /listAllTokenIds endpoint within this API.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Success]:
        """API to invalidate the access token.

        An endpoint which allows you to invalidate a given access token.

        :param invalidate_access_token_request: The endpoint accepts your Client ID, Client Secret ID and the Token ID for the access token you wish to invalidate as part of the request. You can obtain a list of all Token IDs from the /listAllTokenIds endpoint within this API.
        :type invalidate_access_token_request: InvalidateAccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._invalidate_token_serialize(
            invalidate_access_token_request=invalidate_access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Success",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def invalidate_token_without_preload_content(
        self,
        invalidate_access_token_request: Annotated[Optional[InvalidateAccessTokenRequest], Field(description="The endpoint accepts your Client ID, Client Secret ID and the Token ID for the access token you wish to invalidate as part of the request. You can obtain a list of all Token IDs from the /listAllTokenIds endpoint within this API.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """API to invalidate the access token.

        An endpoint which allows you to invalidate a given access token.

        :param invalidate_access_token_request: The endpoint accepts your Client ID, Client Secret ID and the Token ID for the access token you wish to invalidate as part of the request. You can obtain a list of all Token IDs from the /listAllTokenIds endpoint within this API.
        :type invalidate_access_token_request: InvalidateAccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._invalidate_token_serialize(
            invalidate_access_token_request=invalidate_access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Success",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _invalidate_token_serialize(
        self,
        invalidate_access_token_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if invalidate_access_token_request is not None:
            _body_params = invalidate_access_token_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/invalidateToken',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def list_all_token_ids(
        self,
        access_token_request: Annotated[Optional[AccessTokenRequest], Field(description="The endpoint accepts your Client ID and Client Secret ID as part of the request.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AccessTokenIdListResponse:
        """API to list all the access tokens Id.

        An endpoint which allows you to view all active access tokens associated with your Client ID and Client Secret ID.

        :param access_token_request: The endpoint accepts your Client ID and Client Secret ID as part of the request.
        :type access_token_request: AccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_all_token_ids_serialize(
            access_token_request=access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AccessTokenIdListResponse",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_all_token_ids_with_http_info(
        self,
        access_token_request: Annotated[Optional[AccessTokenRequest], Field(description="The endpoint accepts your Client ID and Client Secret ID as part of the request.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AccessTokenIdListResponse]:
        """API to list all the access tokens Id.

        An endpoint which allows you to view all active access tokens associated with your Client ID and Client Secret ID.

        :param access_token_request: The endpoint accepts your Client ID and Client Secret ID as part of the request.
        :type access_token_request: AccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_all_token_ids_serialize(
            access_token_request=access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AccessTokenIdListResponse",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_all_token_ids_without_preload_content(
        self,
        access_token_request: Annotated[Optional[AccessTokenRequest], Field(description="The endpoint accepts your Client ID and Client Secret ID as part of the request.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """API to list all the access tokens Id.

        An endpoint which allows you to view all active access tokens associated with your Client ID and Client Secret ID.

        :param access_token_request: The endpoint accepts your Client ID and Client Secret ID as part of the request.
        :type access_token_request: AccessTokenRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_all_token_ids_serialize(
            access_token_request=access_token_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AccessTokenIdListResponse",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_all_token_ids_serialize(
        self,
        access_token_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if access_token_request is not None:
            _body_params = access_token_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/listAllTokenIds',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.charge import Charge
from unicourt.model.charge_additional_data import ChargeAdditionalData
from unicourt.model.charge_degree import ChargeDegree
from unicourt.model.charge_severity import ChargeSeverity
from typing import Optional, Set
from typing_extensions import Self

class CaseCharge(BaseModel):
    """
    CaseCharge
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=10, strict=True, max_length=10)]] = Field(default='CaseCharge', description="Name of the object")
    charge: Optional[Charge] = None
    charge_degree: Optional[ChargeDegree] = Field(default=None, alias="chargeDegree")
    charge_severity: Optional[ChargeSeverity] = Field(default=None, alias="chargeSeverity")
    charge_additional_data_array: Optional[List[ChargeAdditionalData]] = Field(default=None, alias="chargeAdditionalDataArray")
    __properties: ClassVar[List[str]] = ["object", "charge", "chargeDegree", "chargeSeverity", "chargeAdditionalDataArray"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CaseCharge from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of charge
        if self.charge:
            _dict['charge'] = self.charge.to_dict()
        # override the default output from pydantic by calling `to_dict()` of charge_degree
        if self.charge_degree:
            _dict['chargeDegree'] = self.charge_degree.to_dict()
        # override the default output from pydantic by calling `to_dict()` of charge_severity
        if self.charge_severity:
            _dict['chargeSeverity'] = self.charge_severity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in charge_additional_data_array (list)
        _items = []
        if self.charge_additional_data_array:
            for _item in self.charge_additional_data_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['chargeAdditionalDataArray'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CaseCharge from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'CaseCharge',
            "charge": Charge.from_dict(obj["charge"]) if obj.get("charge") is not None else None,
            "chargeDegree": ChargeDegree.from_dict(obj["chargeDegree"]) if obj.get("chargeDegree") is not None else None,
            "chargeSeverity": ChargeSeverity.from_dict(obj["chargeSeverity"]) if obj.get("chargeSeverity") is not None else None,
            "chargeAdditionalDataArray": [ChargeAdditionalData.from_dict(_item) for _item in obj["chargeAdditionalDataArray"]] if obj.get("chargeAdditionalDataArray") is not None else None
        })
        return _obj





import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated
from datetime import datetime
from pydantic import Field, StrictBool, StrictInt, field_validator
from typing import Optional
from typing_extensions import Annotated
from unicourt.model.case_document import CaseDocument
from unicourt.model.case_document_order_callback import CaseDocumentOrderCallback
from unicourt.model.case_document_order_callback_list_response import CaseDocumentOrderCallbackListResponse
from unicourt.model.case_document_order_request import CaseDocumentOrderRequest
from unicourt.model.case_documents import CaseDocuments
from unicourt.model.document_download import DocumentDownload
from unicourt.api_client import ApiClient, RequestSerialized
from unicourt.api_response import ApiResponse
from unicourt.rest import RESTResponseType
from unicourt.api.case_documents_api import CaseDocumentsApi
from unicourt.sdk_response import SdkResponse
from unicourt import utils
class CaseDocuments:

    @staticmethod
    def get_case_document_download_by_id(
        case_document_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Document ID which you want to download.")],
        is_preview_document: Annotated[Optional[StrictBool], Field(description="If the document you want to download is a preview of a document.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[DocumentDownload]:

        """Gets downloadable URL for a requested Document ID.

        Gets downloadable URL for a requested Document ID.

        :param case_document_id: Document ID which you want to download. (required)
        :type case_document_id: str
        :param is_preview_document: If the document you want to download is a preview of a document.
        :type is_preview_document: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_case_document_download_by_id_with_http_info(case_document_id = case_document_id, is_preview_document = is_preview_document, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_case_document_download_by_id_with_http_info(
        case_document_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Document ID which you want to download.")],
        is_preview_document: Annotated[Optional[StrictBool], Field(description="If the document you want to download is a preview of a document.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DocumentDownload]:

        """Gets downloadable URL for a requested Document ID.

        Gets downloadable URL for a requested Document ID.

        :param case_document_id: Document ID which you want to download. (required)
        :type case_document_id: str
        :param is_preview_document: If the document you want to download is a preview of a document.
        :type is_preview_document: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return CaseDocumentsApi(api_client).get_case_document_download_by_id_with_http_info(case_document_id = case_document_id, is_preview_document = is_preview_document, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def get_case_document_download_by_id_without_preload_content(
        case_document_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Document ID which you want to download.")],
        is_preview_document: Annotated[Optional[StrictBool], Field(description="If the document you want to download is a preview of a document.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Gets downloadable URL for a requested Document ID.

        Gets downloadable URL for a requested Document ID.

        :param case_document_id: Document ID which you want to download. (required)
        :type case_document_id: str
        :param is_preview_document: If the document you want to download is a preview of a document.
        :type is_preview_document: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_case_document_download_by_id_without_preload_content_with_http_info(case_document_id = case_document_id, is_preview_document = is_preview_document, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_case_document_order_callback_by_id(
        case_document_order_callback_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Unique Id for the Case Document Order Callback.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[CaseDocumentOrderCallback]:

        """Get Case Document Order Callback for a requested Case Document Order Callback Id.

        Get Case Document Order Callback for a requested Case Document Order Callback Id.

        :param case_document_order_callback_id: Unique Id for the Case Document Order Callback. (required)
        :type case_document_order_callback_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_case_document_order_callback_by_id_with_http_info(case_document_order_callback_id = case_document_order_callback_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_case_document_order_callback_by_id_with_http_info(
        case_document_order_callback_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Unique Id for the Case Document Order Callback.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CaseDocumentOrderCallback]:

        """Get Case Document Order Callback for a requested Case Document Order Callback Id.

        Get Case Document Order Callback for a requested Case Document Order Callback Id.

        :param case_document_order_callback_id: Unique Id for the Case Document Order Callback. (required)
        :type case_document_order_callback_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return CaseDocumentsApi(api_client).get_case_document_order_callback_by_id_with_http_info(case_document_order_callback_id = case_document_order_callback_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def get_case_document_order_callback_by_id_without_preload_content(
        case_document_order_callback_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Unique Id for the Case Document Order Callback.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Get Case Document Order Callback for a requested Case Document Order Callback Id.

        Get Case Document Order Callback for a requested Case Document Order Callback Id.

        :param case_document_order_callback_id: Unique Id for the Case Document Order Callback. (required)
        :type case_document_order_callback_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_case_document_order_callback_by_id_without_preload_content_with_http_info(case_document_order_callback_id = case_document_order_callback_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_case_document_order_callbacks(
        date: Annotated[Optional[datetime], Field(description="Date for which fetch the Case Document Order Callback list. By default, the date will be set to current date.")] = None,
        status: Annotated[Optional[Annotated[str, Field(min_length=7, strict=True, max_length=11)]], Field(description="Status of Document Order callbacks. Default status will fetch all callbacks.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page to fetch the Case Document Order Callback list.<br>   - Minimum: 1 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[CaseDocumentOrderCallbackListResponse]:

        """Get Case Document Order Callback list for a requested Date.

        Get Case Document Order Callback list for a requested Date.

        :param date: Date for which fetch the Case Document Order Callback list. By default, the date will be set to current date.
        :type date: datetime
        :param status: Status of Document Order callbacks. Default status will fetch all callbacks.
        :type status: str
        :param page_number: Page to fetch the Case Document Order Callback list.<br>   - Minimum: 1 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_case_document_order_callbacks_with_http_info(date = date, status = status, page_number = page_number, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_case_document_order_callbacks_with_http_info(
        date: Annotated[Optional[datetime], Field(description="Date for which fetch the Case Document Order Callback list. By default, the date will be set to current date.")] = None,
        status: Annotated[Optional[Annotated[str, Field(min_length=7, strict=True, max_length=11)]], Field(description="Status of Document Order callbacks. Default status will fetch all callbacks.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page to fetch the Case Document Order Callback list.<br>   - Minimum: 1 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CaseDocumentOrderCallbackListResponse]:

        """Get Case Document Order Callback list for a requested Date.

        Get Case Document Order Callback list for a requested Date.

        :param date: Date for which fetch the Case Document Order Callback list. By default, the date will be set to current date.
        :type date: datetime
        :param status: Status of Document Order callbacks. Default status will fetch all callbacks.
        :type status: str
        :param page_number: Page to fetch the Case Document Order Callback list.<br>   - Minimum: 1 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return CaseDocumentsApi(api_client).get_case_document_order_callbacks_with_http_info(date = date, status = status, page_number = page_number, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def get_case_document_order_callbacks_without_preload_content(
        date: Annotated[Optional[datetime], Field(description="Date for which fetch the Case Document Order Callback list. By default, the date will be set to current date.")] = None,
        status: Annotated[Optional[Annotated[str, Field(min_length=7, strict=True, max_length=11)]], Field(description="Status of Document Order callbacks. Default status will fetch all callbacks.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page to fetch the Case Document Order Callback list.<br>   - Minimum: 1 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Get Case Document Order Callback list for a requested Date.

        Get Case Document Order Callback list for a requested Date.

        :param date: Date for which fetch the Case Document Order Callback list. By default, the date will be set to current date.
        :type date: datetime
        :param status: Status of Document Order callbacks. Default status will fetch all callbacks.
        :type status: str
        :param page_number: Page to fetch the Case Document Order Callback list.<br>   - Minimum: 1 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_case_document_order_callbacks_without_preload_content_with_http_info(date = date, status = status, page_number = page_number, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_case_documents(
        case_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Case ID for which you want the data for.")],
        in_library: Annotated[Optional[StrictBool], Field(description="Filter all the documents those are added to the UniCourt library.")] = None,
        after_first_fetch_date: Annotated[Optional[datetime], Field(description="Get all the documents which were added to the case on or after a specific date.")] = None,
        library_date: Annotated[Optional[datetime], Field(description="Sort all the documents based on the date when the document was added to the UniCourt Library.")] = None,
        first_fetch_date: Annotated[Optional[datetime], Field(description="Sort all the documents based on the date it was fetched from the source site.")] = None,
        sort_by: Annotated[Optional[Annotated[str, Field(min_length=10, strict=True, max_length=20)]], Field(description="Sort documents with document order.")] = None,
        page_number: Annotated[Optional[StrictInt], Field(description="The page for which the result should be retrieved.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[CaseDocuments]:

        """Gets Documents for a requested Case ID.

        Gets Documents for a requested Case ID.

        :param case_id: Case ID for which you want the data for. (required)
        :type case_id: str
        :param in_library: Filter all the documents those are added to the UniCourt library.
        :type in_library: bool
        :param after_first_fetch_date: Get all the documents which were added to the case on or after a specific date.
        :type after_first_fetch_date: datetime
        :param library_date: Sort all the documents based on the date when the document was added to the UniCourt Library.
        :type library_date: datetime
        :param first_fetch_date: Sort all the documents based on the date it was fetched from the source site.
        :type first_fetch_date: datetime
        :param sort_by: Sort documents with document order.
        :type sort_by: str
        :param page_number: The page for which the result should be retrieved.
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_case_documents_with_http_info(case_id = case_id, in_library = in_library, after_first_fetch_date = after_first_fetch_date, library_date = library_date, first_fetch_date = first_fetch_date, sort_by = sort_by, page_number = page_number, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_case_documents_with_http_info(
        case_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Case ID for which you want the data for.")],
        in_library: Annotated[Optional[StrictBool], Field(description="Filter all the documents those are added to the UniCourt library.")] = None,
        after_first_fetch_date: Annotated[Optional[datetime], Field(description="Get all the documents which were added to the case on or after a specific date.")] = None,
        library_date: Annotated[Optional[datetime], Field(description="Sort all the documents based on the date when the document was added to the UniCourt Library.")] = None,
        first_fetch_date: Annotated[Optional[datetime], Field(description="Sort all the documents based on the date it was fetched from the source site.")] = None,
        sort_by: Annotated[Optional[Annotated[str, Field(min_length=10, strict=True, max_length=20)]], Field(description="Sort documents with document order.")] = None,
        page_number: Annotated[Optional[StrictInt], Field(description="The page for which the result should be retrieved.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CaseDocuments]:

        """Gets Documents for a requested Case ID.

        Gets Documents for a requested Case ID.

        :param case_id: Case ID for which you want the data for. (required)
        :type case_id: str
        :param in_library: Filter all the documents those are added to the UniCourt library.
        :type in_library: bool
        :param after_first_fetch_date: Get all the documents which were added to the case on or after a specific date.
        :type after_first_fetch_date: datetime
        :param library_date: Sort all the documents based on the date when the document was added to the UniCourt Library.
        :type library_date: datetime
        :param first_fetch_date: Sort all the documents based on the date it was fetched from the source site.
        :type first_fetch_date: datetime
        :param sort_by: Sort documents with document order.
        :type sort_by: str
        :param page_number: The page for which the result should be retrieved.
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return CaseDocumentsApi(api_client).get_case_documents_with_http_info(case_id = case_id, in_library = in_library, after_first_fetch_date = after_first_fetch_date, library_date = library_date, first_fetch_date = first_fetch_date, sort_by = sort_by, page_number = page_number, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def get_case_documents_without_preload_content(
        case_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Case ID for which you want the data for.")],
        in_library: Annotated[Optional[StrictBool], Field(description="Filter all the documents those are added to the UniCourt library.")] = None,
        after_first_fetch_date: Annotated[Optional[datetime], Field(description="Get all the documents which were added to the case on or after a specific date.")] = None,
        library_date: Annotated[Optional[datetime], Field(description="Sort all the documents based on the date when the document was added to the UniCourt Library.")] = None,
        first_fetch_date: Annotated[Optional[datetime], Field(description="Sort all the documents based on the date it was fetched from the source site.")] = None,
        sort_by: Annotated[Optional[Annotated[str, Field(min_length=10, strict=True, max_length=20)]], Field(description="Sort documents with document order.")] = None,
        page_number: Annotated[Optional[StrictInt], Field(description="The page for which the result should be retrieved.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Gets Documents for a requested Case ID.

        Gets Documents for a requested Case ID.

        :param case_id: Case ID for which you want the data for. (required)
        :type case_id: str
        :param in_library: Filter all the documents those are added to the UniCourt library.
        :type in_library: bool
        :param after_first_fetch_date: Get all the documents which were added to the case on or after a specific date.
        :type after_first_fetch_date: datetime
        :param library_date: Sort all the documents based on the date when the document was added to the UniCourt Library.
        :type library_date: datetime
        :param first_fetch_date: Sort all the documents based on the date it was fetched from the source site.
        :type first_fetch_date: datetime
        :param sort_by: Sort documents with document order.
        :type sort_by: str
        :param page_number: The page for which the result should be retrieved.
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_case_documents_without_preload_content_with_http_info(case_id = case_id, in_library = in_library, after_first_fetch_date = after_first_fetch_date, library_date = library_date, first_fetch_date = first_fetch_date, sort_by = sort_by, page_number = page_number, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_document_by_id(
        case_document_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Specific Case Dcoument ID for which you want the data for.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[CaseDocument]:

        """Gets details for a requested Document ID.

        Gets details for a requested Document ID.

        :param case_document_id: Specific Case Dcoument ID for which you want the data for. (required)
        :type case_document_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_document_by_id_with_http_info(case_document_id = case_document_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def get_document_by_id_with_http_info(
        case_document_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Specific Case Dcoument ID for which you want the data for.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CaseDocument]:

        """Gets details for a requested Document ID.

        Gets details for a requested Document ID.

        :param case_document_id: Specific Case Dcoument ID for which you want the data for. (required)
        :type case_document_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return CaseDocumentsApi(api_client).get_document_by_id_with_http_info(case_document_id = case_document_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def get_document_by_id_without_preload_content(
        case_document_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Specific Case Dcoument ID for which you want the data for.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Gets details for a requested Document ID.

        Gets details for a requested Document ID.

        :param case_document_id: Specific Case Dcoument ID for which you want the data for. (required)
        :type case_document_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).get_document_by_id_without_preload_content_with_http_info(case_document_id = case_document_id, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def order_case_document(
        case_document_order_request: Annotated[Optional[CaseDocumentOrderRequest], Field(description="If the Case Document Order is for Preview, then the value for ``isPreviewOnly`` should be ``true`` else ``false``. ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[CaseDocumentOrderCallback]:

        """Add Case Document Order for requested Document Ids.

        Add Case Document Order for requested Document Ids. The status will be ``IN_PROGRESS`` after it has been requested. If the request is not processed within 4 hours, it will be reported as ``DELAYED``.  If the request is still incomplete after 4 hours, it will remain in the DELAYED status for up to 72 hours after the request was approved. Such requests will be recorded as ``TIMEOUT`` after 72 hours. The progress of this Case Document Order request is available via web socket messages documented on <a href=\"https://sapp.unicourt.com/developers/enterpriseapi/api/UniCourt-Enterprise-Callback-Async-API-Spec/#caseDocumentOrder\">  WebSocket Callbacks Documentation </a>

        :param case_document_order_request: If the Case Document Order is for Preview, then the value for ``isPreviewOnly`` should be ``true`` else ``false``. 
        :type case_document_order_request: CaseDocumentOrderRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).order_case_document_with_http_info(case_document_order_request = case_document_order_request, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)

    @staticmethod
    def order_case_document_with_http_info(
        case_document_order_request: Annotated[Optional[CaseDocumentOrderRequest], Field(description="If the Case Document Order is for Preview, then the value for ``isPreviewOnly`` should be ``true`` else ``false``. ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CaseDocumentOrderCallback]:

        """Add Case Document Order for requested Document Ids.

        Add Case Document Order for requested Document Ids. The status will be ``IN_PROGRESS`` after it has been requested. If the request is not processed within 4 hours, it will be reported as ``DELAYED``.  If the request is still incomplete after 4 hours, it will remain in the DELAYED status for up to 72 hours after the request was approved. Such requests will be recorded as ``TIMEOUT`` after 72 hours. The progress of this Case Document Order request is available via web socket messages documented on <a href=\"https://sapp.unicourt.com/developers/enterpriseapi/api/UniCourt-Enterprise-Callback-Async-API-Spec/#caseDocumentOrder\">  WebSocket Callbacks Documentation </a>

        :param case_document_order_request: If the Case Document Order is for Preview, then the value for ``isPreviewOnly`` should be ``true`` else ``false``. 
        :type case_document_order_request: CaseDocumentOrderRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            return CaseDocumentsApi(api_client).order_case_document_with_http_info(case_document_order_request = case_document_order_request, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)

    @staticmethod
    def order_case_document_without_preload_content(
        case_document_order_request: Annotated[Optional[CaseDocumentOrderRequest], Field(description="If the Case Document Order is for Preview, then the value for ``isPreviewOnly`` should be ``true`` else ``false``. ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SdkResponse[RESTResponseType]:

        """Add Case Document Order for requested Document Ids.

        Add Case Document Order for requested Document Ids. The status will be ``IN_PROGRESS`` after it has been requested. If the request is not processed within 4 hours, it will be reported as ``DELAYED``.  If the request is still incomplete after 4 hours, it will remain in the DELAYED status for up to 72 hours after the request was approved. Such requests will be recorded as ``TIMEOUT`` after 72 hours. The progress of this Case Document Order request is available via web socket messages documented on <a href=\"https://sapp.unicourt.com/developers/enterpriseapi/api/UniCourt-Enterprise-Callback-Async-API-Spec/#caseDocumentOrder\">  WebSocket Callbacks Documentation </a>

        :param case_document_order_request: If the Case Document Order is for Preview, then the value for ``isPreviewOnly`` should be ``true`` else ``false``. 
        :type case_document_order_request: CaseDocumentOrderRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """
        with utils.api_client() as api_client:
            response = CaseDocumentsApi(api_client).order_case_document_without_preload_content_with_http_info(case_document_order_request = case_document_order_request, _request_timeout = _request_timeout, _request_auth = _request_auth, _content_type = _content_type, _headers = _headers, _host_index = _host_index)
            return (response.data, response.status_code)



# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.pacer_case_search_content import PACERCaseSearchContent
from typing import Optional, Set
from typing_extensions import Self

class PACERPartySearchContent(BaseModel):
    """
    PACERPartySearchContent
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=23, strict=True, max_length=23)]] = Field(default='PACERPartySearchContent', description="Name of the object")
    pcl_jurisdiction_type: Optional[StrictStr] = Field(default=None, description="Link to case in the case management/electronic case files (CM/ECF) system at the court.", alias="pclJurisdictionType")
    pcl_case_id: Optional[StrictInt] = Field(default=None, description="Sequentially generated number that identifies the case.", alias="pclCaseId")
    pcl_case_number_full: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="Case Number.", alias="pclCaseNumberFull")
    pcl_case_title: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Title of the case.", alias="pclCaseTitle")
    pcl_case_office: Optional[Annotated[str, Field(strict=True, max_length=2)]] = Field(default=None, description="The divisional office in which the case was filed.", alias="pclCaseOffice")
    pcl_case_number: Optional[StrictInt] = Field(default=None, description="The sequence number of the case.", alias="pclCaseNumber")
    pcl_case_type: Optional[Annotated[str, Field(strict=True, max_length=6)]] = Field(default=None, description="Code that identifies the type of case.", alias="pclCaseType")
    pcl_case_year: Optional[StrictInt] = Field(default=None, description="The year in which the case falls. Could be two or four digit.", alias="pclCaseYear")
    pcl_court_id: Optional[Annotated[str, Field(strict=True, max_length=6)]] = Field(default=None, description="The general geographical region or specific court district. The court ID is the abbreviation of the court location combined with the court type (dc or bk). Please refer the Appendix B", alias="pclCourtId")
    pcl_date_filed: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="Filing date of the case.", alias="pclDateFiled")
    pcl_last_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="This parameter represents the last name of the case when it is present", alias="pclLastName")
    pcl_first_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="This parameter represents the first name of the case when it is present", alias="pclFirstName")
    pcl_middle_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="This parameter represents the middle name of the case when it is present", alias="pclMiddleName")
    pcl_generation: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the generation of the case when it is present", alias="pclGeneration")
    pcl_party_role: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the party role of the case when it is present", alias="pclPartyRole")
    pcl_party_type: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the party type of the case when it is present", alias="pclPartyType")
    pcl_court_case: Optional[PACERCaseSearchContent] = Field(default=None, alias="pclCourtCase")
    __properties: ClassVar[List[str]] = ["object", "pclJurisdictionType", "pclCaseId", "pclCaseNumberFull", "pclCaseTitle", "pclCaseOffice", "pclCaseNumber", "pclCaseType", "pclCaseYear", "pclCourtId", "pclDateFiled", "pclLastName", "pclFirstName", "pclMiddleName", "pclGeneration", "pclPartyRole", "pclPartyType", "pclCourtCase"]

    @field_validator('pcl_jurisdiction_type')
    def pcl_jurisdiction_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Appellate', 'Bankruptcy', 'Criminal', 'Civil', 'Multi-district Litigation', 'null']):
            raise ValueError("must be one of enum values ('Appellate', 'Bankruptcy', 'Criminal', 'Civil', 'Multi-district Litigation', 'null')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PACERPartySearchContent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of pcl_court_case
        if self.pcl_court_case:
            _dict['pclCourtCase'] = self.pcl_court_case.to_dict()
        # set to None if pcl_jurisdiction_type (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_jurisdiction_type is None and "pcl_jurisdiction_type" in self.model_fields_set:
            _dict['pclJurisdictionType'] = None

        # set to None if pcl_case_number_full (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_case_number_full is None and "pcl_case_number_full" in self.model_fields_set:
            _dict['pclCaseNumberFull'] = None

        # set to None if pcl_case_title (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_case_title is None and "pcl_case_title" in self.model_fields_set:
            _dict['pclCaseTitle'] = None

        # set to None if pcl_case_office (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_case_office is None and "pcl_case_office" in self.model_fields_set:
            _dict['pclCaseOffice'] = None

        # set to None if pcl_case_type (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_case_type is None and "pcl_case_type" in self.model_fields_set:
            _dict['pclCaseType'] = None

        # set to None if pcl_court_id (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_court_id is None and "pcl_court_id" in self.model_fields_set:
            _dict['pclCourtId'] = None

        # set to None if pcl_date_filed (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_date_filed is None and "pcl_date_filed" in self.model_fields_set:
            _dict['pclDateFiled'] = None

        # set to None if pcl_last_name (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_last_name is None and "pcl_last_name" in self.model_fields_set:
            _dict['pclLastName'] = None

        # set to None if pcl_first_name (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_first_name is None and "pcl_first_name" in self.model_fields_set:
            _dict['pclFirstName'] = None

        # set to None if pcl_middle_name (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_middle_name is None and "pcl_middle_name" in self.model_fields_set:
            _dict['pclMiddleName'] = None

        # set to None if pcl_generation (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_generation is None and "pcl_generation" in self.model_fields_set:
            _dict['pclGeneration'] = None

        # set to None if pcl_party_role (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_party_role is None and "pcl_party_role" in self.model_fields_set:
            _dict['pclPartyRole'] = None

        # set to None if pcl_party_type (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_party_type is None and "pcl_party_type" in self.model_fields_set:
            _dict['pclPartyType'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PACERPartySearchContent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'PACERPartySearchContent',
            "pclJurisdictionType": obj.get("pclJurisdictionType"),
            "pclCaseId": obj.get("pclCaseId"),
            "pclCaseNumberFull": obj.get("pclCaseNumberFull"),
            "pclCaseTitle": obj.get("pclCaseTitle"),
            "pclCaseOffice": obj.get("pclCaseOffice"),
            "pclCaseNumber": obj.get("pclCaseNumber"),
            "pclCaseType": obj.get("pclCaseType"),
            "pclCaseYear": obj.get("pclCaseYear"),
            "pclCourtId": obj.get("pclCourtId"),
            "pclDateFiled": obj.get("pclDateFiled"),
            "pclLastName": obj.get("pclLastName"),
            "pclFirstName": obj.get("pclFirstName"),
            "pclMiddleName": obj.get("pclMiddleName"),
            "pclGeneration": obj.get("pclGeneration"),
            "pclPartyRole": obj.get("pclPartyRole"),
            "pclPartyType": obj.get("pclPartyType"),
            "pclCourtCase": PACERCaseSearchContent.from_dict(obj["pclCourtCase"]) if obj.get("pclCourtCase") is not None else None
        })
        return _obj





from unicourt.sdk.JudgeAnalytics import JudgeAnalytics


class TestJudgeAnalytics:
    def test_get_norm_attorneys_associated_with_norm_judge():
        return JudgeAnalytics.get_norm_attorneys_associated_with_norm_judge(
            norm_judge_id='NJUDT7jCZyFNeLGpRq',
            page_number=1,
            q='caseTypeId:"CTYPATMYyaJekdgj2c" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00]'
        )

    def test_get_norm_judge_by_id():
        return JudgeAnalytics.get_norm_judge_by_id(
            norm_judge_id='NJUDT7jCZyFNeLGpRq'
        )

    def test_get_norm_law_firms_associated_with_norm_judge():
        return JudgeAnalytics.get_norm_law_firms_associated_with_norm_judge(
            norm_judge_id='NJUDT7jCZyFNeLGpRq',
            page_number=1,
            q='caseTypeId:"CTYPATMYyaJekdgj2c" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00]'
        )

    def test_get_norm_parties_associated_with_norm_judge():
        return JudgeAnalytics.get_norm_parties_associated_with_norm_judge(
            q='caseTypeId:"CTYPATMYyaJekdgj2c" AND caseFiledDate:[2017-01-01T00:00:00+00:00TO2021-11-30T00:00:00+00:00]',
            norm_judge_id='NJUDT7jCZyFNeLGpRq',
            page_number=1
        )

    def test_search_normalized_judges():
        return JudgeAnalytics. search_normalized_judges(
            q='normJudgeId:"NJUD5STmDbUZGukfQm"'
        )

    def test_search_normalized_judges_by_id():
        return JudgeAnalytics. search_normalized_judges_by_id(
            norm_judge_search_id='JSRCNUSK3pLGe48QcU'
        )



from unicourt.sdk.CaseSearch import CaseSearch


class TestCaseSearch:
    def test_search_cases():
        return CaseSearch.search_cases(
            q='caseNumber:"JP07-22-DC00026818"',
            sort='filedDate',
            order='desc',
            page_number=1
        )

    def test_search_cases_by_id():
        return CaseSearch.search_cases_by_id(
            case_search_id='CSRCU3qFUH8BjLnba5'
        )



# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class PACERCaseSearchContent(BaseModel):
    """
    PACERCaseSearchContent
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=22, strict=True, max_length=22)]] = Field(default='PACERCaseSearchContent', description="Name of the object")
    pcl_case_link: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Link to case in the case management/electronic case files (CM/ECF) system at the court.", alias="pclCaseLink")
    pcl_jurisdiction_type: Optional[StrictStr] = Field(default=None, description="Link to case in the case management/electronic case files (CM/ECF) system at the court.", alias="pclJurisdictionType")
    pcl_case_id: Optional[StrictInt] = Field(default=None, description="Sequentially generated number that identifies the case.", alias="pclCaseId")
    pcl_case_number_full: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="Case Number.", alias="pclCaseNumberFull")
    pcl_case_title: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Title of the case.", alias="pclCaseTitle")
    pcl_case_office: Optional[Annotated[str, Field(strict=True, max_length=2)]] = Field(default=None, description="The divisional office in which the case was filed.", alias="pclCaseOffice")
    pcl_case_number: Optional[StrictInt] = Field(default=None, description="The sequence number of the case.", alias="pclCaseNumber")
    pcl_case_type: Optional[Annotated[str, Field(strict=True, max_length=6)]] = Field(default=None, description="Code that identifies the type of case.", alias="pclCaseType")
    pcl_case_year: Optional[StrictInt] = Field(default=None, description="The year in which the case falls. Could be two or four digit.", alias="pclCaseYear")
    pcl_court_id: Optional[Annotated[str, Field(strict=True, max_length=6)]] = Field(default=None, description="The general geographical region or specific court district. The court ID is the abbreviation of the court location combined with the court type (dc or bk). Please refer the Appendix B", alias="pclCourtId")
    pcl_date_filed: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="Filing date of the case.", alias="pclDateFiled")
    pcl_jpml_number: Optional[StrictInt] = Field(default=None, description="JPML Case Seed number.", alias="pclJpmlNumber")
    pcl_mdl_court_id: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="Which court does this mdl belongs too.", alias="pclMdlCourtId")
    pcl_mdl_date_ordered: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the mdl date ordered of the case when it is present", alias="pclMdlDateOrdered")
    pcl_mdl_date_received: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the mdl date received of the case when it is present", alias="pclMdlDateReceived")
    pcl_mdl_extension: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the mdl extension of the case when it is present", alias="pclMdlExtension")
    pcl_mdl_judge_last_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the mdl judge lastname of the case when it is present", alias="pclMdlJudgeLastName")
    pcl_mdl_littype: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the mdl lit type of the case when it is present", alias="pclMdlLittype")
    pcl_mdl_status: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the mdl status of the case when it is present", alias="pclMdlStatus")
    pcl_mdl_transferee: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the mdl transferee of the case when it is present", alias="pclMdlTransferee")
    pcl_mdl_transferee_district: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the mdl transferee district of the case when it is present", alias="pclMdlTransfereeDistrict")
    pcl_civil_cto_number: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the civil cto number of the case when it is present", alias="pclCivilCtoNumber")
    pcl_civil_date_disposition: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the civil disposition date of the case when it is present", alias="pclCivilDateDisposition")
    pcl_civil_date_initiated: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the civil initiated date of the case when it is present", alias="pclCivilDateInitiated")
    pcl_civil_date_terminated: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the civil terminated date of the case when it is present", alias="pclCivilDateTerminated")
    pcl_civil_stat_disposition: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the civil stat disposition of the case when it is present", alias="pclCivilStatDisposition")
    pcl_civil_stat_initiated: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the civil stat initiated of the case when it is present", alias="pclCivilStatInitiated")
    pcl_civil_stat_terminated: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the civil stat terminated of the case when it is present", alias="pclCivilStatTerminated")
    pcl_civil_transferee: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the civil transferee of the case when it is present", alias="pclCivilTransferee")
    pcl_bankruptcy_chapter: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the bankruptcy chapter of the case when it is present", alias="pclBankruptcyChapter")
    pcl_date_discharged: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the date discharged of the case when it is present", alias="pclDateDischarged")
    pcl_date_dismissed: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the date dismissed of the case when it is present", alias="pclDateDismissed")
    pcl_date_reopened: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the date reopened of the case when it is present", alias="pclDateReopened")
    pcl_date_termed: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the date termed of the case when it is present", alias="pclDateTermed")
    pcl_disposition: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="This parameter represents the disposition of the case when it is present", alias="pclDisposition")
    pcl_disposition_method: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="This parameter represents the disposition method of the case when it is present", alias="pclDispositionMethod")
    pcl_joint_bankruptcy_flag: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the joint bankruptcy flag of the case when it is present", alias="pclJointBankruptcyFlag")
    pcl_joint_discharged_date: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the joint discharged date of the case when it is present", alias="pclJointDischargedDate")
    pcl_joint_dismissed_date: Optional[Annotated[str, Field(strict=True, max_length=10)]] = Field(default=None, description="This parameter represents the joint dismissed date of the case when it is present", alias="pclJointDismissedDate")
    pcl_joint_disposition_method: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="This parameter represents the joint disposition method of the case when it is present", alias="pclJointDispositionMethod")
    pcl_nature_of_suit: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="This parameter represents the nature of suit of the case when it is present", alias="pclNatureOfSuit")
    __properties: ClassVar[List[str]] = ["object", "pclCaseLink", "pclJurisdictionType", "pclCaseId", "pclCaseNumberFull", "pclCaseTitle", "pclCaseOffice", "pclCaseNumber", "pclCaseType", "pclCaseYear", "pclCourtId", "pclDateFiled", "pclJpmlNumber", "pclMdlCourtId", "pclMdlDateOrdered", "pclMdlDateReceived", "pclMdlExtension", "pclMdlJudgeLastName", "pclMdlLittype", "pclMdlStatus", "pclMdlTransferee", "pclMdlTransfereeDistrict", "pclCivilCtoNumber", "pclCivilDateDisposition", "pclCivilDateInitiated", "pclCivilDateTerminated", "pclCivilStatDisposition", "pclCivilStatInitiated", "pclCivilStatTerminated", "pclCivilTransferee", "pclBankruptcyChapter", "pclDateDischarged", "pclDateDismissed", "pclDateReopened", "pclDateTermed", "pclDisposition", "pclDispositionMethod", "pclJointBankruptcyFlag", "pclJointDischargedDate", "pclJointDismissedDate", "pclJointDispositionMethod", "pclNatureOfSuit"]

    @field_validator('pcl_jurisdiction_type')
    def pcl_jurisdiction_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Appellate', 'Bankruptcy', 'Criminal', 'Civil', 'Multi-district Litigation', 'null']):
            raise ValueError("must be one of enum values ('Appellate', 'Bankruptcy', 'Criminal', 'Civil', 'Multi-district Litigation', 'null')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PACERCaseSearchContent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if pcl_case_link (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_case_link is None and "pcl_case_link" in self.model_fields_set:
            _dict['pclCaseLink'] = None

        # set to None if pcl_jurisdiction_type (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_jurisdiction_type is None and "pcl_jurisdiction_type" in self.model_fields_set:
            _dict['pclJurisdictionType'] = None

        # set to None if pcl_case_number_full (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_case_number_full is None and "pcl_case_number_full" in self.model_fields_set:
            _dict['pclCaseNumberFull'] = None

        # set to None if pcl_case_title (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_case_title is None and "pcl_case_title" in self.model_fields_set:
            _dict['pclCaseTitle'] = None

        # set to None if pcl_case_office (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_case_office is None and "pcl_case_office" in self.model_fields_set:
            _dict['pclCaseOffice'] = None

        # set to None if pcl_case_type (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_case_type is None and "pcl_case_type" in self.model_fields_set:
            _dict['pclCaseType'] = None

        # set to None if pcl_court_id (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_court_id is None and "pcl_court_id" in self.model_fields_set:
            _dict['pclCourtId'] = None

        # set to None if pcl_date_filed (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_date_filed is None and "pcl_date_filed" in self.model_fields_set:
            _dict['pclDateFiled'] = None

        # set to None if pcl_jpml_number (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_jpml_number is None and "pcl_jpml_number" in self.model_fields_set:
            _dict['pclJpmlNumber'] = None

        # set to None if pcl_mdl_court_id (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_mdl_court_id is None and "pcl_mdl_court_id" in self.model_fields_set:
            _dict['pclMdlCourtId'] = None

        # set to None if pcl_mdl_date_ordered (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_mdl_date_ordered is None and "pcl_mdl_date_ordered" in self.model_fields_set:
            _dict['pclMdlDateOrdered'] = None

        # set to None if pcl_mdl_date_received (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_mdl_date_received is None and "pcl_mdl_date_received" in self.model_fields_set:
            _dict['pclMdlDateReceived'] = None

        # set to None if pcl_mdl_extension (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_mdl_extension is None and "pcl_mdl_extension" in self.model_fields_set:
            _dict['pclMdlExtension'] = None

        # set to None if pcl_mdl_judge_last_name (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_mdl_judge_last_name is None and "pcl_mdl_judge_last_name" in self.model_fields_set:
            _dict['pclMdlJudgeLastName'] = None

        # set to None if pcl_mdl_littype (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_mdl_littype is None and "pcl_mdl_littype" in self.model_fields_set:
            _dict['pclMdlLittype'] = None

        # set to None if pcl_mdl_status (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_mdl_status is None and "pcl_mdl_status" in self.model_fields_set:
            _dict['pclMdlStatus'] = None

        # set to None if pcl_mdl_transferee (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_mdl_transferee is None and "pcl_mdl_transferee" in self.model_fields_set:
            _dict['pclMdlTransferee'] = None

        # set to None if pcl_mdl_transferee_district (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_mdl_transferee_district is None and "pcl_mdl_transferee_district" in self.model_fields_set:
            _dict['pclMdlTransfereeDistrict'] = None

        # set to None if pcl_civil_cto_number (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_civil_cto_number is None and "pcl_civil_cto_number" in self.model_fields_set:
            _dict['pclCivilCtoNumber'] = None

        # set to None if pcl_civil_date_disposition (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_civil_date_disposition is None and "pcl_civil_date_disposition" in self.model_fields_set:
            _dict['pclCivilDateDisposition'] = None

        # set to None if pcl_civil_date_initiated (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_civil_date_initiated is None and "pcl_civil_date_initiated" in self.model_fields_set:
            _dict['pclCivilDateInitiated'] = None

        # set to None if pcl_civil_date_terminated (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_civil_date_terminated is None and "pcl_civil_date_terminated" in self.model_fields_set:
            _dict['pclCivilDateTerminated'] = None

        # set to None if pcl_civil_stat_disposition (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_civil_stat_disposition is None and "pcl_civil_stat_disposition" in self.model_fields_set:
            _dict['pclCivilStatDisposition'] = None

        # set to None if pcl_civil_stat_initiated (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_civil_stat_initiated is None and "pcl_civil_stat_initiated" in self.model_fields_set:
            _dict['pclCivilStatInitiated'] = None

        # set to None if pcl_civil_stat_terminated (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_civil_stat_terminated is None and "pcl_civil_stat_terminated" in self.model_fields_set:
            _dict['pclCivilStatTerminated'] = None

        # set to None if pcl_civil_transferee (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_civil_transferee is None and "pcl_civil_transferee" in self.model_fields_set:
            _dict['pclCivilTransferee'] = None

        # set to None if pcl_bankruptcy_chapter (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_bankruptcy_chapter is None and "pcl_bankruptcy_chapter" in self.model_fields_set:
            _dict['pclBankruptcyChapter'] = None

        # set to None if pcl_date_discharged (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_date_discharged is None and "pcl_date_discharged" in self.model_fields_set:
            _dict['pclDateDischarged'] = None

        # set to None if pcl_date_dismissed (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_date_dismissed is None and "pcl_date_dismissed" in self.model_fields_set:
            _dict['pclDateDismissed'] = None

        # set to None if pcl_date_reopened (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_date_reopened is None and "pcl_date_reopened" in self.model_fields_set:
            _dict['pclDateReopened'] = None

        # set to None if pcl_date_termed (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_date_termed is None and "pcl_date_termed" in self.model_fields_set:
            _dict['pclDateTermed'] = None

        # set to None if pcl_disposition (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_disposition is None and "pcl_disposition" in self.model_fields_set:
            _dict['pclDisposition'] = None

        # set to None if pcl_disposition_method (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_disposition_method is None and "pcl_disposition_method" in self.model_fields_set:
            _dict['pclDispositionMethod'] = None

        # set to None if pcl_joint_bankruptcy_flag (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_joint_bankruptcy_flag is None and "pcl_joint_bankruptcy_flag" in self.model_fields_set:
            _dict['pclJointBankruptcyFlag'] = None

        # set to None if pcl_joint_discharged_date (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_joint_discharged_date is None and "pcl_joint_discharged_date" in self.model_fields_set:
            _dict['pclJointDischargedDate'] = None

        # set to None if pcl_joint_dismissed_date (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_joint_dismissed_date is None and "pcl_joint_dismissed_date" in self.model_fields_set:
            _dict['pclJointDismissedDate'] = None

        # set to None if pcl_joint_disposition_method (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_joint_disposition_method is None and "pcl_joint_disposition_method" in self.model_fields_set:
            _dict['pclJointDispositionMethod'] = None

        # set to None if pcl_nature_of_suit (nullable) is None
        # and model_fields_set contains the field
        if self.pcl_nature_of_suit is None and "pcl_nature_of_suit" in self.model_fields_set:
            _dict['pclNatureOfSuit'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PACERCaseSearchContent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'PACERCaseSearchContent',
            "pclCaseLink": obj.get("pclCaseLink"),
            "pclJurisdictionType": obj.get("pclJurisdictionType"),
            "pclCaseId": obj.get("pclCaseId"),
            "pclCaseNumberFull": obj.get("pclCaseNumberFull"),
            "pclCaseTitle": obj.get("pclCaseTitle"),
            "pclCaseOffice": obj.get("pclCaseOffice"),
            "pclCaseNumber": obj.get("pclCaseNumber"),
            "pclCaseType": obj.get("pclCaseType"),
            "pclCaseYear": obj.get("pclCaseYear"),
            "pclCourtId": obj.get("pclCourtId"),
            "pclDateFiled": obj.get("pclDateFiled"),
            "pclJpmlNumber": obj.get("pclJpmlNumber"),
            "pclMdlCourtId": obj.get("pclMdlCourtId"),
            "pclMdlDateOrdered": obj.get("pclMdlDateOrdered"),
            "pclMdlDateReceived": obj.get("pclMdlDateReceived"),
            "pclMdlExtension": obj.get("pclMdlExtension"),
            "pclMdlJudgeLastName": obj.get("pclMdlJudgeLastName"),
            "pclMdlLittype": obj.get("pclMdlLittype"),
            "pclMdlStatus": obj.get("pclMdlStatus"),
            "pclMdlTransferee": obj.get("pclMdlTransferee"),
            "pclMdlTransfereeDistrict": obj.get("pclMdlTransfereeDistrict"),
            "pclCivilCtoNumber": obj.get("pclCivilCtoNumber"),
            "pclCivilDateDisposition": obj.get("pclCivilDateDisposition"),
            "pclCivilDateInitiated": obj.get("pclCivilDateInitiated"),
            "pclCivilDateTerminated": obj.get("pclCivilDateTerminated"),
            "pclCivilStatDisposition": obj.get("pclCivilStatDisposition"),
            "pclCivilStatInitiated": obj.get("pclCivilStatInitiated"),
            "pclCivilStatTerminated": obj.get("pclCivilStatTerminated"),
            "pclCivilTransferee": obj.get("pclCivilTransferee"),
            "pclBankruptcyChapter": obj.get("pclBankruptcyChapter"),
            "pclDateDischarged": obj.get("pclDateDischarged"),
            "pclDateDismissed": obj.get("pclDateDismissed"),
            "pclDateReopened": obj.get("pclDateReopened"),
            "pclDateTermed": obj.get("pclDateTermed"),
            "pclDisposition": obj.get("pclDisposition"),
            "pclDispositionMethod": obj.get("pclDispositionMethod"),
            "pclJointBankruptcyFlag": obj.get("pclJointBankruptcyFlag"),
            "pclJointDischargedDate": obj.get("pclJointDischargedDate"),
            "pclJointDismissedDate": obj.get("pclJointDismissedDate"),
            "pclJointDispositionMethod": obj.get("pclJointDispositionMethod"),
            "pclNatureOfSuit": obj.get("pclNatureOfSuit")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner(BaseModel):
    """
    BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner
    """ # noqa: E501
    final_decision: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="finalDecision")
    final_decision_date: Optional[datetime] = Field(default=None, alias="finalDecisionDate")
    grievance_complaint_number: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="grievanceComplaintNumber")
    public_comments: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = Field(default=None, alias="publicComments")
    __properties: ClassVar[List[str]] = ["finalDecision", "finalDecisionDate", "grievanceComplaintNumber", "publicComments"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if final_decision (nullable) is None
        # and model_fields_set contains the field
        if self.final_decision is None and "final_decision" in self.model_fields_set:
            _dict['finalDecision'] = None

        # set to None if final_decision_date (nullable) is None
        # and model_fields_set contains the field
        if self.final_decision_date is None and "final_decision_date" in self.model_fields_set:
            _dict['finalDecisionDate'] = None

        # set to None if grievance_complaint_number (nullable) is None
        # and model_fields_set contains the field
        if self.grievance_complaint_number is None and "grievance_complaint_number" in self.model_fields_set:
            _dict['grievanceComplaintNumber'] = None

        # set to None if public_comments (nullable) is None
        # and model_fields_set contains the field
        if self.public_comments is None and "public_comments" in self.model_fields_set:
            _dict['publicComments'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BarSourceDataStatewideGrievanceCommitteeHistoryArrayInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "finalDecision": obj.get("finalDecision"),
            "finalDecisionDate": obj.get("finalDecisionDate"),
            "grievanceComplaintNumber": obj.get("grievanceComplaintNumber"),
            "publicComments": obj.get("publicComments")
        })
        return _obj


